pymodaq_plugins_alcatel
########################

Authors
=======

* Titouan Gadeyne  (titouan.gadeyne@cea.fr)


Instruments
===========

Below is the list of instruments included in this plugin

Viewer0D
++++++++

* **ACM1000**: Alcatel ACM 1000 six-port gauge controller


Installation instructions
=========================

* PyMoDAQ 4
* Windows 10
* No drivers from Alcatel are required.
* Your PC should have serial ports (COM ports) to connect the controller. On Windows 10 you may need to install a driver to create virtual COM ports.
